chessboard.tests package
========================

Submodules
----------

chessboard.tests.test_board module
----------------------------------

.. automodule:: chessboard.tests.test_board
    :members:
    :undoc-members:
    :show-inheritance:

chessboard.tests.test_pieces module
-----------------------------------

.. automodule:: chessboard.tests.test_pieces
    :members:
    :undoc-members:
    :show-inheritance:

chessboard.tests.test_solver module
-----------------------------------

.. automodule:: chessboard.tests.test_solver
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: chessboard.tests
    :members:
    :undoc-members:
    :show-inheritance:
